summaryrefslogtreecommitdiffstats
path: root/sys/vdpau
diff options
context:
space:
mode:
authorCarl-Anton Ingmarsson <ca.ingmarsson@gmail.com>2009-04-14 21:04:59 +0200
committerJan Schmidt <thaytan@noraisin.net>2009-06-20 15:21:28 +0100
commit4470b61f8064758a2998d8b513304e0854170321 (patch)
tree741a2c3ebccd4ce3c0b2aa87f0814a4414085b44 /sys/vdpau
parent71c398566cf9f434d9a8fd7b98224c0e1f963910 (diff)
downloadgst-plugins-bad-4470b61f8064758a2998d8b513304e0854170321.tar.gz
gst-plugins-bad-4470b61f8064758a2998d8b513304e0854170321.tar.bz2
gst-plugins-bad-4470b61f8064758a2998d8b513304e0854170321.zip
vdpaumpegdecoder: rename to "vdpaumpegdec"
Diffstat (limited to 'sys/vdpau')
-rw-r--r--sys/vdpau/gstvdp.c2
-rw-r--r--sys/vdpau/gstvdpmpegdecoder.c10
2 files changed, 6 insertions, 6 deletions
diff --git a/sys/vdpau/gstvdp.c b/sys/vdpau/gstvdp.c
index 9ca0114e..b18c8a02 100644
--- a/sys/vdpau/gstvdp.c
+++ b/sys/vdpau/gstvdp.c
@@ -12,7 +12,7 @@
static gboolean
vdpau_init (GstPlugin * vdpau_plugin)
{
- gst_element_register (vdpau_plugin, "vdpaumpegdecoder",
+ gst_element_register (vdpau_plugin, "vdpaumpegdec",
GST_RANK_NONE, GST_TYPE_VDPAU_MPEG_DECODER);
gst_element_register (vdpau_plugin, "vdpauvideoyuv",
GST_RANK_NONE, GST_TYPE_VDPAU_VIDEO_YUV);
diff --git a/sys/vdpau/gstvdpmpegdecoder.c b/sys/vdpau/gstvdpmpegdecoder.c
index 350414a7..e1f9e56c 100644
--- a/sys/vdpau/gstvdpmpegdecoder.c
+++ b/sys/vdpau/gstvdpmpegdecoder.c
@@ -19,14 +19,14 @@
*/
/**
- * SECTION:element-vdpaumpegdecoder
+ * SECTION:element-vdpaumpegdec
*
* FIXME:Describe vdpaumpegdecoder here.
*
* <refsect2>
* <title>Example launch line</title>
* |[
* gst-launch -v -m fakesrc ! vdpaumpegdecoder ! fakesink silent=TRUE
* ]|
* </refsect2>
*/
@@ -68,7 +68,7 @@ static GstStaticPadTemplate sink_factory = GST_STATIC_PAD_TEMPLATE ("sink",
);
#define DEBUG_INIT(bla) \
-GST_DEBUG_CATEGORY_INIT (gst_vdp_mpeg_decoder_debug, "vdpaumpegdecoder", 0, "VDPAU powered mpeg decoder");
+GST_DEBUG_CATEGORY_INIT (gst_vdp_mpeg_decoder_debug, "vdpaumpegdec", 0, "VDPAU powered mpeg decoder");
GST_BOILERPLATE_FULL (GstVdpMpegDecoder, gst_vdp_mpeg_decoder,
GstVdpDecoder, GST_TYPE_VDPAU_DECODER, DEBUG_INIT);
@@ -384,7 +384,7 @@ gst_vdp_mpeg_decoder_base_init (gpointer gclass)
GstElementClass *element_class = GST_ELEMENT_CLASS (gclass);
gst_element_class_set_details_simple (element_class,
- "VdpauMpegDecoder",
+ "VDPAU Mpeg Decoder",
"Decoder",
"decode mpeg stream with vdpau",
"Carl-Anton Ingmarsson <ca.ingmarsson@gmail.com>");
@@ -19,14 +19,14 @@
*
- * FIXME:Describe vdpaumpegdecoder here.
+ * FIXME:Describe vdpaumpegdec here.
*
* <refsect2>
@@ -19,14 +19,14 @@
* <title>Example launch line</title>
* |[
- * gst-launch -v -m fakesrc ! vdpaumpegdecoder ! fakesink silent=TRUE
+ * gst-launch -v -m fakesrc ! vdpaumpegdec ! fakesink silent=TRUE
* ]|
* </refsect2>